"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _BaseClient_payload, _BaseClient_config;
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseClient = void 0;
const https_1 = require("https");
const Constants_1 = require("../utils/Constants");
const eventemitter3_1 = require("eventemitter3");
const axios_1 = __importDefault(require("axios"));
/**
 * Base Client for the Client to extend
 * @extends EventEmitter
 */
class BaseClient extends eventemitter3_1.EventEmitter {
    /**
     * @param config Options to initialize the BaseClient with
     * @param payload The payload for the client if applicable
     */
    constructor(config = {}, payload = {}) {
        super();
        _BaseClient_payload.set(this, void 0);
        _BaseClient_config.set(this, void 0);
        // Set defaults
        __classPrivateFieldSet(this, _BaseClient_config, Object.assign(BaseClient.DEFAULT_CONFIG, config), "f");
        const headers = Object.assign(Constants_1.DefaultHeaders, config?.headers);
        this.instance = axios_1.default.create({
            baseURL: `https://${Constants_1.APIBase}/v${Constants_1.APIVersion}`,
            headers,
            httpsAgent: new https_1.Agent({ keepAlive: true }),
        });
        __classPrivateFieldSet(this, _BaseClient_payload, Object.assign({}, payload), "f");
    }
    /**
     * Current config for the Client
     */
    get config() {
        return __classPrivateFieldGet(this, _BaseClient_config, "f");
    }
    /**
     * Gets the payload
     */
    get payload() {
        return __classPrivateFieldGet(this, _BaseClient_payload, "f");
    }
    /**
     * Prevents overwriting the payload
     */
    set payload(value) {
        __classPrivateFieldSet(this, _BaseClient_payload, Object.assign(this.payload, value), "f");
    }
    /**
     * Calls eval with the client set as the "this" context.
     * @param script The script to evaluate
     * @returns The result of the script
     */
    _eval(script) {
        return eval(script);
    }
}
exports.BaseClient = BaseClient;
_BaseClient_payload = new WeakMap(), _BaseClient_config = new WeakMap();
/**
 * Default Config for the Client
 */
BaseClient.DEFAULT_CONFIG = {
    basic: null,
    basic_length: 112,
    bearer: null,
    headers: Constants_1.DefaultHeaders,
    client_id: Constants_1.DefaultClientId,
    client_secret: Constants_1.DefaultClientSecret,
    cache_config: {
        ttl: 1000 * 60 * 30,
        isLazy: true,
        isCachedForever: false,
        calculateKey: JSON.stringify,
    },
};
exports.default = BaseClient;
//# sourceMappingURL=BaseClient.js.map