"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _Client_users, _Client_feeds, _Client_content, _Client_util;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const BaseClient_1 = require("./BaseClient");
const CaptchaError_1 = require("../errors/CaptchaError");
const ContentManager_1 = require("../managers/ContentManager");
const FeedManager_1 = require("../managers/FeedManager");
const iFunnyError_1 = require("../errors/iFunnyError");
const UserManager_1 = require("../managers/UserManager");
const Util_1 = require("../utils/Util");
/**
 * Client for the iFunny API.
 * @extends BaseClient
 * @template Authorized
 */
class Client extends BaseClient_1.BaseClient {
    /**
     * @param config The config for the Client
     * @param payload Payload for the client if applicable
     */
    constructor(config, payload = {}) {
        super(config, payload);
        /**
         * User manager object
         */
        _Client_users.set(this, void 0);
        /**
         * Feed manager object
         */
        _Client_feeds.set(this, void 0);
        /**
         * Content manager object
         */
        _Client_content.set(this, void 0);
        /**
         * Client utility class
         */
        _Client_util.set(this, void 0);
        __classPrivateFieldSet(this, _Client_util, new Util_1.Util(this), "f");
        __classPrivateFieldSet(this, _Client_users, new UserManager_1.UserManager(this, this.config.cache_config), "f");
        __classPrivateFieldSet(this, _Client_content, new ContentManager_1.ContentManager(this, this.config.cache_config), "f");
        __classPrivateFieldSet(this, _Client_feeds, new FeedManager_1.FeedManager(this), "f");
        this.instance.interceptors.request.use((config) => {
            config.headers ?? (config.headers = this.config.headers);
            config.headers.Authorization = this.authorization;
            return config;
        });
        this.instance.interceptors.response.use((onSuccess) => onSuccess, (onFail) => {
            if (!this.util.isAxiosError(onFail) || !onFail.response)
                throw onFail;
            if (!this.util.isAPIError(onFail.response.data))
                throw onFail;
            if (iFunnyError_1.iFunnyError.isRawCaptchaError(this, onFail.response.data)) {
                throw new CaptchaError_1.CaptchaError(this, onFail.response.data);
            }
            throw new iFunnyError_1.iFunnyError(this, onFail.response.data);
        });
    }
    /**
     * Utility class for the client
     */
    get util() {
        return __classPrivateFieldGet(this, _Client_util, "f");
    }
    /**
     * Basic token used by the client.\
     * If not set in constructor, one was generated
     */
    get basic() {
        return (this.config.basic ||
            this.util.createBasicAuth({
                clientId: this.config.client_id,
                clientSecret: this.config.client_secret,
                length: this.config.basic_length,
            }));
    }
    /**
     * Sets the basic token for the Client. Must be a string
     */
    set basic(value) {
        this.config.basic = value;
    }
    /**
     * The bearer token for the client
     */
    get bearer() {
        return this.config.bearer;
    }
    /**
     * Sets the bearer token for the client. If set to null, the client will not use a bearer token.
     */
    set bearer(value) {
        this.config.bearer = value || null;
        this.instance.defaults.headers.common.Authorization = this.is_authorized()
            ? `Bearer ${this.bearer}`
            : `Basic ${this.basic}`;
    }
    /**
     * The authorization string used for requests
     */
    get authorization() {
        return this.bearer ? `Bearer ${this.bearer}` : `Basic ${this.basic}`;
    }
    /**
     * Is the client using a bearer token to make requests?
     */
    is_authorized() {
        return !!this.bearer;
    }
    /**
     * Updates the Client's payload
     * @returns The Client instance
     */
    async fetch() {
        if (!this.is_authorized()) {
            throw new Error("Client is not authorized with a bearer token. Please generate one with Client#login");
        }
        const response = await this.instance.get(ifunny_api_types_1.Endpoints.account);
        const data = response.data;
        this.payload = data.data;
        return this;
    }
    /**
     * The client's user manager
     */
    get users() {
        return __classPrivateFieldGet(this, _Client_users, "f");
    }
    /**
     * The content feeds for the Client
     */
    get feeds() {
        return __classPrivateFieldGet(this, _Client_feeds, "f");
    }
    /**
     * The Client's Content manager
     */
    get content() {
        return __classPrivateFieldGet(this, _Client_content, "f");
    }
    /**
     * Logs into iFunny with an Email and Password\
     * If you already have a bearer token, don't use this method
     * @param email The email to login with
     * @param password The password to login with
     * @returns The Client instance
     */
    async login(email, password) {
        if (this.is_authorized()) {
            return await this.fetch();
        }
        if (!email || !password) {
            throw new TypeError("email and password are required if a bearer hasn't been set");
        }
        const auth = `Basic ${this.basic}`;
        const data = new FormData();
        data.set("grant_type", "password");
        data.set("username", email);
        data.set("password", password);
        const response = await this.instance.post(ifunny_api_types_1.Endpoints.token, data, {
            headers: {
                accept: "application/json",
                applicationstate: 1,
                authorization: auth,
                connection: "Keep-Alive",
                "content-type": "application/x-www-form-urlencoded",
            },
        });
        this.bearer = response.data.access_token;
        return await this.fetch();
    }
    /**
     * Signs up for an iFunny account.
     * @param options.nick The nick of the account to sign up with. Checks if the nick is taken.
     * @param options.email The email to sign up with. Checks if the email is taken.
     * @param options.password The password to sign up with
     * @param options.acceptMailOffers Should the Client sign up for the mailing list. Never set this to true.
     * @param options.login Should the client login after sign up? (Default: true)
     * @returns The instance of the client
     */
    async sign_up(options) {
        const data = new FormData();
        data.set("reg_type", "pwd");
        data.set("nick", options.nick);
        data.set("email", options.email);
        data.set("password", options.password);
        data.set("accept_mailing", !!options.accept_mailing ? "1" : "0");
        const response = await this.instance.post(ifunny_api_types_1.Endpoints.user(), data.toString());
        this.payload.id = response.data.data.id;
        if (options.login ?? true) {
            return await this.login(options.email, options.password);
        }
        return this;
    }
}
exports.Client = Client;
_Client_users = new WeakMap(), _Client_feeds = new WeakMap(), _Client_content = new WeakMap(), _Client_util = new WeakMap();
exports.default = Client;
//# sourceMappingURL=Client.js.map