"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _Base_client, _Base_payload, _Base_endpoint_url;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Base = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
/**
 * Base class for all structures.
 * @template Payload
 */
class Base {
    /**
     * @param client The client instance
     * @param payload The payload of the object
     */
    constructor(client, payload) {
        /**
         * Client instance attached to the Object
         */
        _Base_client.set(this, void 0);
        /**
         * The payload of the object.
         */
        _Base_payload.set(this, void 0);
        /**
         * Endpoint url the object will request to
         */
        _Base_endpoint_url.set(this, ifunny_api_types_1.Endpoints.account);
        __classPrivateFieldSet(this, _Base_client, client, "f");
        __classPrivateFieldSet(this, _Base_payload, payload, "f");
    }
    /**
     * The client instance attached to the Object
     */
    get client() {
        return __classPrivateFieldGet(this, _Base_client, "f");
    }
    /**
     * Get the payload of the object
     */
    get payload() {
        return __classPrivateFieldGet(this, _Base_payload, "f");
    }
    /**
     * Updates the payload of the object.
     * @param payload The payload to merge into the current instance
     * @returns The current instance
     */
    set payload(payload) {
        Object.assign(__classPrivateFieldGet(this, _Base_payload, "f"), payload);
    }
    /**
     * Endpoint url for requests to update the payload
     */
    get endpoint_url() {
        return __classPrivateFieldGet(this, _Base_endpoint_url, "f");
    }
    set endpoint_url(value) {
        __classPrivateFieldSet(this, _Base_endpoint_url, `${value}`, "f");
    }
    /**
     * Fetches the objects data from it's endpoint
     * @returns The instance of the object
     */
    async fetch() {
        const response = await this.client.instance.get(this.endpoint_url);
        return (this.payload = response.data.data);
    }
    /**
     * Gets the value from the payload from its key
     * @param key The key to get the value of
     * @returns
     */
    get(key) {
        // @ts-ignore
        return (this.payload[key] ?? null);
    }
    /**
     * The unique id of the object
     */
    get id() {
        return this.get("id");
    }
    /**
     * Creates a new instance of the same structure with the same payload.
     * @returns A clone of the current instance
     */
    _clone() {
        return Object.assign(Object.create(this), this);
    }
    /**
     * @returns The object's id
     */
    valueOf() {
        return this.id;
    }
    /**
     * Converts the object instance into JSON
     * @returns Stringified payload of the object
     */
    toJSON() {
        return JSON.stringify(this.payload, null, 2);
    }
}
exports.Base = Base;
_Base_client = new WeakMap(), _Base_payload = new WeakMap(), _Base_endpoint_url = new WeakMap();
exports.default = Base;
//# sourceMappingURL=Base.js.map