"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseUser = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const BanSmall_1 = require("./BanSmall");
const Base_1 = require("./Base");
const MemeExperience_1 = require("./MemeExperience");
/**
 * Base User class that user class will inherit from.
 * @extends Base<APIUserProfile>
 */
class BaseUser extends Base_1.Base {
    /**
     * @param client The client instance
     * @param payload Payload to create the User with
     */
    constructor(client, payload) {
        super(client, payload);
        this.payload = payload;
        this.endpoint_url = ifunny_api_types_1.Endpoints.user(payload.id);
    }
    /**
     * The user's about text
     * @alias bio
     */
    get about() {
        return this.get("about");
    }
    /**
     * Does the user have you blocked?
     */
    get are_you_blocked() {
        return this.get("are_you_blocked");
    }
    /**
     * Collection of Bans the user has
     */
    get bans() {
        const bans = this.get("bans") ?? [];
        return bans.map((ban) => new BanSmall_1.BanSmall(this.client, this, ban));
    }
    /**
     * The user's about text
     * @alias about
     */
    get bio() {
        return this.about;
    }
    /**
     * The block type if the user is blocked
     */
    get block_type() {
        return this.get("block_type");
    }
    /**
     * Can the Client chat with the user?\
     * ? Not checked by the backend
     * @alias is_available_for_chat
     */
    get can_chat() {
        return this.is_available_for_chat;
    }
    /**
     * The user's chat privacy
     */
    get chat_privacy() {
        return this.get("messaging_privacy_status");
    }
    /**
     * Cover image background color
     */
    get cover_color() {
        return this.get("cover_bg_color");
    }
    /**
     * Cover imamge url
     */
    get cover_url() {
        return this.get("cover_url");
    }
    /**
     * Can the Client chat with the user?\
     * ? Not checked by the backend
     * @alias can_chat
     */
    get is_available_for_chat() {
        return this.get("is_available_for_chat");
    }
    /**
     * Is the user banned?
     */
    get is_banned() {
        return this.get("is_banned");
    }
    /**
     * Is the user blocked by the Client?
     */
    get is_blocked() {
        return this.get("is_blocked");
    }
    /**
     * Is the user deleted?
     */
    get is_deleted() {
        return this.get("is_deleted");
    }
    /**
     * Is the user's account private?
     */
    get is_private() {
        return this.get("is_private");
    }
    /**
     * Is the user subscribed to updates?
     */
    get is_subscribed_to_updates() {
        return this.get("is_subscribed_to_updates");
    }
    /**
     * Is the user subscribed to the Client?
     */
    get is_subscriber() {
        return this.get("is_in_subscribers");
    }
    /**
     * Is the client subscribed to the user?
     */
    get is_subscription() {
        return this.get("is_in_subscriptions");
    }
    /**
     * Is the user verified?
     */
    get is_verified() {
        return this.get("is_verified");
    }
    /**
     * The user's unique uri
     * @alias web_url
     */
    get link() {
        return this.get("web_url");
    }
    /**
     * The user's meme experience
     */
    get meme_experience() {
        return new MemeExperience_1.MemeExperience(this.get("meme_experience"));
    }
    /**
     * TODO: Add description for messengerActive
     */
    get messenger_active() {
        return this.get("messenger_active");
    }
    /**
     * TODO: Add description for messenger_token
     */
    get messenger_token() {
        return this.get("messenger_token");
    }
    /**
     * Nickname of the user
     * @alias username
     */
    get nick() {
        return this.get("nick");
    }
    /**
     * The nick color of the user if they have one, else null
     */
    get nick_color() {
        return this.get("nick_color");
    }
    /**
     * The users `num` object
     * @alias `stats`
     */
    get num() {
        return this.get("num");
    }
    /**
     * Profile photo of the user
     */
    get profile_photo() {
        return this.get("photo");
    }
    /**
     * All the user's linked social media accounts
     */
    get socials() {
        return this.get("social");
    }
    /**
     * The users  `num` object
     * @alias num
     */
    get stats() {
        return this.num;
    }
    /**
     * The users subscription count
     */
    get total_subscriptions() {
        return this.num.subscriptions;
    }
    /**
     * The users subsciber count
     */
    get total_subscribers() {
        this.payload;
        return this.num.subscribers;
    }
    /**
     * How many posts the user has on their profile
     */
    get total_posts() {
        return this.num.total_posts;
    }
    /**
     * How many original posts the user has
     */
    get total_original_posts() {
        return this.num.created;
    }
    /**
     * How many posts the has that are republishes (***NOT original***)
     */
    get total_republished_posts() {
        return this.total_posts - this.total_original_posts;
    }
    /**
     * How many features the user has
     */
    get total_features() {
        return this.num.featured;
    }
    /**
     * How many smiles the user has on their profile
     */
    get total_smiles() {
        return this.num.total_smiles;
    }
    /**
     * How many achievements the user has
     */
    get total_achievements() {
        return this.num.achievements;
    }
    /**
     * Nickname of the user
     * @alias nick
     */
    get username() {
        return this.nick;
    }
}
exports.BaseUser = BaseUser;
exports.default = BaseUser;
//# sourceMappingURL=BaseUser.js.map