"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _Thumbnail_thumb;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Thumbnail = void 0;
/**
 * Represents a thumbnail for Content on iFunny
 */
class Thumbnail {
    /**
     * @param thumbnail Thumbnail data from the API
     */
    constructor(thumbnail) {
        _Thumbnail_thumb.set(this, void 0);
        __classPrivateFieldSet(this, _Thumbnail_thumb, thumbnail, "f");
    }
    /**
     * Gets the value for the thumbnail from its key
     * @param key Key for the thumbnail
     * @returns Type safe value from the key
     */
    get(key) {
        return __classPrivateFieldGet(this, _Thumbnail_thumb, "f")[key];
    }
    /**
     * Thumbnail Content Id. This is different from the Content Id
     */
    get id() {
        const id = this.url.match(Thumbnail.Thumbnail_ID_Regex);
        if (!id) {
            throw new Error(`Thumbnail Id Regex too specific. Couldn't get ID for: ${this.url}`);
        }
        return id[0];
    }
    /**
     * Create a new thumbnail with custom parameters
     * @param params Params for the new thumbnail
     * @param extension File extension for the thumbnail. (Default: `jpg`)
     */
    create(params, extension = "jpg") {
        return `https://imageproxy.ifunny.co/${params}/images/${this.id}.${extension}`;
    }
    /**
     * The thumbnail url after cropping out the iFunny Watermark
     */
    get cropped() {
        return this.create("crop:x-20");
    }
    get large_url() {
        return this.get("large_url");
    }
    get large_webp_url() {
        return this.get("large_webp_url");
    }
    get proportional_size() {
        return this.get("proportional_size");
    }
    get proportional_url() {
        return this.get("proportional_url");
    }
    get proportional_webp_url() {
        return this.get("proportional_webp_url");
    }
    get small_url() {
        return this.get("small_url");
    }
    get url() {
        return this.get("url");
    }
    get webp_url() {
        return this.get("webp_url");
    }
    get x640_url() {
        return this.get("x640_url");
    }
    get x640_webp_url() {
        return this.get("x640_webp_url");
    }
}
exports.Thumbnail = Thumbnail;
_Thumbnail_thumb = new WeakMap();
Thumbnail.Thumbnail_ID_Regex = /(?<=^https\:\/\/imageproxy\.ifunny\.co\/[a-z0-9:,-]+\/[a-z]+\/)([a-z0-9_]+)(?=\.[a-z]{3,4}$)/gi;
exports.default = Thumbnail;
//# sourceMappingURL=Thumbnail.js.map