import { APIClientUser as ClientPayload } from "@ifunny/ifunny-api-types";
import { EventEmitter } from "eventemitter3";
import { ICachingOptions } from "node-ts-cache";
import { AxiosRequestHeaders } from "axios";
export interface ClientConfig {
    basic: string | null;
    basic_length: 156 | 112;
    bearer: string | null;
    headers: AxiosRequestHeaders;
    client_id: string;
    client_secret: string;
    cache_config: ICachingOptions;
}
export declare type ClientOptions = Partial<ClientConfig>;
/**
 * Base Client for the Client to extend
 * @extends EventEmitter
 */
export declare class BaseClient extends EventEmitter {
    #private;
    /**
     * @param config Options to initialize the BaseClient with
     * @param payload The payload for the client if applicable
     */
    constructor(config?: ClientOptions, payload?: Partial<ClientPayload>);
    /**
     * Default Config for the Client
     */
    static readonly DEFAULT_CONFIG: ClientConfig;
    /**
     * Current config for the Client
     */
    get config(): ClientConfig;
    /**
     * Gets the payload
     */
    get payload(): Partial<ClientPayload>;
    /**
     * Prevents overwriting the payload
     */
    set payload(value: Partial<ClientPayload>);
    /**
     * Calls eval with the client set as the "this" context.
     * @param script The script to evaluate
     * @returns The result of the script
     */
    protected _eval(script: string): any;
}
export default BaseClient;
//# sourceMappingURL=BaseClient.d.ts.map