import { APIBan, APIBanReason, APIBanType } from "@ifunny/ifunny-api-types";
import { Base } from "./Base";
import { Comment } from "./Comment";
import { Content } from "./Content";
import { User } from "./User";
/**
 * Represents a complete Ban Object on iFunny
 * @extends Base<APIBan>
 */
export declare class Ban extends Base<APIBan> {
    #private;
    /**
     * @param user User the ban is attached to
     * @param payload The payload of the Ban
     */
    constructor(user: User, payload: APIBan);
    /**
     * The user attached to the Ban
     */
    get user(): User;
    /**
     * The type of ban
     */
    get type(): APIBanType;
    /**
     * Timestamp of when the Ban expires
     */
    get expires_at(): Date;
    /**
     * How long (in miliseconds) until the Ban expires
     */
    get expires_in(): number;
    /**
     * The reason for the Ban
     */
    get reason(): APIBanReason;
    /**
     * The ban reason message
     */
    get reason_message(): string | null;
    /**
     * Can the ban be appeald?
     */
    get can_be_appealed(): boolean;
    /**
     * When the ban was created
     */
    get created_at(): Date;
    /**
     * Not sure what this is
     */
    get date_until_minimum(): number | null;
    /**
     * Is the Ban active?
     */
    get is_active(): boolean;
    /**
     * Has the Ban be appealed?
     */
    get is_appealed(): boolean;
    /**
     * Is the ban shortable?
     */
    get is_shortable(): boolean;
    /**
     * Don't know what this is yet
     */
    get pid(): number;
    /**
     * The Comment related to the Ban if applicable
     */
    get related_comment(): Comment | null;
    /**
     * The Content related to the Ban if applicable
     */
    get related_content(): Content | null;
    /**
     * The Ban Type message
     */
    get type_message(): string | null;
    /**
     * Was the Ban shown to the Client?
     */
    get was_shown(): boolean;
}
export default Ban;
//# sourceMappingURL=Ban.d.ts.map