import { APIBasePayload } from "@ifunny/ifunny-api-types";
import { Client } from "../client/Client";
import { Nullify } from "../utils/Types";
/**
 * Base class for all structures.
 * @template Payload
 */
export declare class Base<Payload extends APIBasePayload> {
    #private;
    /**
     * @param client The client instance
     * @param payload The payload of the object
     */
    constructor(client: Client, payload: Payload);
    /**
     * The client instance attached to the Object
     */
    get client(): Client<boolean>;
    /**
     * Get the payload of the object
     */
    get payload(): Payload;
    /**
     * Updates the payload of the object.
     * @param payload The payload to merge into the current instance
     * @returns The current instance
     */
    set payload(payload: Partial<Payload>);
    /**
     * Endpoint url for requests to update the payload
     */
    protected get endpoint_url(): string;
    protected set endpoint_url(value: string);
    /**
     * Fetches the objects data from it's endpoint
     * @returns The instance of the object
     */
    fetch(): Promise<this>;
    /**
     * Gets the value from the payload from its key
     * @param key The key to get the value of
     * @returns
     */
    protected get<P extends Payload, K extends keyof P>(key: K): Nullify<P[K]>;
    /**
     * The unique id of the object
     */
    get id(): string;
    /**
     * Creates a new instance of the same structure with the same payload.
     * @returns A clone of the current instance
     */
    protected _clone(): this;
    /**
     * @returns The object's id
     */
    valueOf(): string;
    /**
     * Converts the object instance into JSON
     * @returns Stringified payload of the object
     */
    toJSON(): string;
}
export default Base;
//# sourceMappingURL=Base.d.ts.map