import { APIContent, APIContentCopyright, APIContentData, APIContentNums, APIContentShotStatus, APIContentSource, APIContentState, APIContentThumbnail, APIContentType, APIContentVisibility, APIFeedFrom, Size } from "@ifunny/ifunny-api-types";
import { Base } from "./Base";
import { Client } from "../client/Client";
import { Creator } from "./Creator";
/**
 * The Base Content that all Content Types will extend
 * @extends Base<APIContent>
 */
export declare class BaseContent extends Base<APIContent> {
    #private;
    /**
     * @param client Client instance associated with the Content
     * @param payload Payload of the Content
     */
    constructor(client: Client, payload: APIContent);
    /**
     * This data is typically retrieved by using the content's type as a key for the content.
     * @example
     * content.payload[content.type] // Key isn't always the type
     */
    get data(): APIContentData | null;
    /**
     * The creator of the post
     * @alias creator
     */
    get author(): Creator | null;
    /**
     * Content background color
     */
    get bg_color(): string;
    /**
     * Can the post be boosted?
     */
    get can_be_boosted(): boolean;
    /**
     * Content url that can be opened in app
     */
    get canonical_url(): string;
    /**
     * Copywright information attached to the content
     */
    get copyright(): APIContentCopyright;
    /**
     * The creator of the post
     * @alias author
     */
    get creator(): Creator | null;
    /**
     * When the content was created
     */
    get created_at(): Date;
    /**
     * Not sure what this is
     */
    get fast_start(): boolean;
    /**
     * Title set by iFunny
     */
    get fixed_title(): string;
    /**
     * The ID of the Content.
     */
    get id(): string;
    /**
     * Was the post removed by iFunny
     */
    get is_abused(): boolean;
    /**
     * Was the post featured
     */
    get is_featured(): boolean;
    /**
     * Is the Content pinned by the author
     */
    get is_pinned(): boolean;
    /**
     * Is the Content republished by the Client
     */
    get is_republished(): boolean;
    /**
     * Is the Content smiled by the Client
     */
    get is_smiled(): boolean;
    /**
     * When the Content was featured if it was featured
     */
    get featured_at(): Date | null;
    /**
     * The tag to use for the 'from' parameter
     */
    get ftag(): APIFeedFrom | null;
    /**
     * The link of the content that can be opened in iFunny
     */
    get link(): string;
    /**
     * The numbers attached to the Content
     * @alias stats
     */
    get num(): APIContentNums;
    /**
     * Text generated from iFunny's OCR (Optical Character Recognition)
     */
    get ocr_text(): string | null;
    /**
     * Does the Content use the Old Watermark
     */
    get old_watermark(): boolean;
    /**
     * When the Content was published or will publish
     */
    get published_at(): Date;
    /**
     * The risk level of the Content\
     * Default: `1`
     */
    get risk(): number;
    /**
     * The shot status of the content\
     * `approved` - Content can be posted in comments\
     * `shot` - Content can't be posted in comments\
     * `hardShot` - Content was removed by iFunny and is not viewable
     */
    get shot_status(): APIContentShotStatus;
    /**
     * The size of the Content
     */
    get size(): Size;
    /**
     * The source of the content if it exists
     */
    get source(): APIContentSource | null;
    /**
     * The state of the Content
     */
    get state(): APIContentState;
    /**
     * The numbers attached to the Content
     * @alias num
     */
    get stats(): APIContentNums;
    /**
     * All tags on the Content
     */
    get tags(): string[];
    /**
     * Thumbnail of the Content
     */
    get thumbnail(): APIContentThumbnail;
    /**
     * The Title of the content
     */
    get title(): string;
    /**
     * URL of the original source if it exists
     */
    get traceback_url(): string | null;
    /**
     * The type of the post
     */
    get type(): APIContentType;
    /**
     * URL of the Content
     */
    get url(): string;
    /**
     * The Content's visibility status\
     * `public` - Content shows up in collective and explore
     * `subscribers` - Content is hidden from Collective and Explore
     * `closed` - Content is not visible by anyone but the author
     */
    get visibility(): APIContentVisibility;
}
export default BaseContent;
//# sourceMappingURL=BaseContent.d.ts.map