import { APINickColor, APIProfilePhoto, APIUserAllSocials, APIUserBlockType, APIUserMessagePrivacy, APIUserProfile, APIUserProfileNums } from "@ifunny/ifunny-api-types";
import { BanSmall } from "./BanSmall";
import { Base } from "./Base";
import { Client } from "../client/Client";
import { MemeExperience } from "./MemeExperience";
/**
 * Base User class that user class will inherit from.
 * @extends Base<APIUserProfile>
 */
export declare class BaseUser extends Base<APIUserProfile> {
    /**
     * @param client The client instance
     * @param payload Payload to create the User with
     */
    constructor(client: Client, payload: APIUserProfile);
    /**
     * The user's about text
     * @alias bio
     */
    get about(): string;
    /**
     * Does the user have you blocked?
     */
    get are_you_blocked(): boolean;
    /**
     * Collection of Bans the user has
     */
    get bans(): BanSmall[];
    /**
     * The user's about text
     * @alias about
     */
    get bio(): string;
    /**
     * The block type if the user is blocked
     */
    get block_type(): APIUserBlockType | null;
    /**
     * Can the Client chat with the user?\
     * ? Not checked by the backend
     * @alias is_available_for_chat
     */
    get can_chat(): boolean;
    /**
     * The user's chat privacy
     */
    get chat_privacy(): APIUserMessagePrivacy;
    /**
     * Cover image background color
     */
    get cover_color(): string | null;
    /**
     * Cover imamge url
     */
    get cover_url(): string | null;
    /**
     * Can the Client chat with the user?\
     * ? Not checked by the backend
     * @alias can_chat
     */
    get is_available_for_chat(): boolean;
    /**
     * Is the user banned?
     */
    get is_banned(): boolean;
    /**
     * Is the user blocked by the Client?
     */
    get is_blocked(): boolean;
    /**
     * Is the user deleted?
     */
    get is_deleted(): boolean;
    /**
     * Is the user's account private?
     */
    get is_private(): boolean;
    /**
     * Is the user subscribed to updates?
     */
    get is_subscribed_to_updates(): boolean;
    /**
     * Is the user subscribed to the Client?
     */
    get is_subscriber(): boolean;
    /**
     * Is the client subscribed to the user?
     */
    get is_subscription(): boolean;
    /**
     * Is the user verified?
     */
    get is_verified(): boolean;
    /**
     * The user's unique uri
     * @alias web_url
     */
    get link(): string;
    /**
     * The user's meme experience
     */
    get meme_experience(): MemeExperience;
    /**
     * TODO: Add description for messengerActive
     */
    get messenger_active(): boolean;
    /**
     * TODO: Add description for messenger_token
     */
    get messenger_token(): string;
    /**
     * Nickname of the user
     * @alias username
     */
    get nick(): string;
    /**
     * The nick color of the user if they have one, else null
     */
    get nick_color(): APINickColor | null;
    /**
     * The users `num` object
     * @alias `stats`
     */
    get num(): APIUserProfileNums;
    /**
     * Profile photo of the user
     */
    get profile_photo(): APIProfilePhoto | null;
    /**
     * All the user's linked social media accounts
     */
    get socials(): APIUserAllSocials | null;
    /**
     * The users  `num` object
     * @alias num
     */
    get stats(): APIUserProfileNums;
    /**
     * The users subscription count
     */
    get total_subscriptions(): number;
    /**
     * The users subsciber count
     */
    get total_subscribers(): number;
    /**
     * How many posts the user has on their profile
     */
    get total_posts(): number;
    /**
     * How many original posts the user has
     */
    get total_original_posts(): number;
    /**
     * How many posts the has that are republishes (***NOT original***)
     */
    get total_republished_posts(): number;
    /**
     * How many features the user has
     */
    get total_features(): number;
    /**
     * How many smiles the user has on their profile
     */
    get total_smiles(): number;
    /**
     * How many achievements the user has
     */
    get total_achievements(): number;
    /**
     * Nickname of the user
     * @alias nick
     */
    get username(): string;
}
export default BaseUser;
//# sourceMappingURL=BaseUser.d.ts.map