import { APIContent, APIFeedFrom } from "@ifunny/ifunny-api-types";
import { BaseContent } from "./BaseContent";
import { Client } from "../client/Client";
import { SimpleUser } from "./SimpleUser";
/**
 * Represents content from iFunny
 * @extends BaseContent
 */
export declare class Content extends BaseContent {
    #private;
    /**
     * @param client Client attached to the Content
     * @param payload Payload of the content
     */
    constructor(client: Client, payload: APIContent);
    /**
     * Cycles through users that smiled the post
     * @param limit How many users to return per request (Default: `30`)
     */
    smiles(limit?: number): AsyncGenerator<SimpleUser, void, unknown>;
    /**
     * Smiles the post
     * @param from Where the action occured
     * @returns Was it success
     */
    smile(from?: APIFeedFrom): Promise<boolean>;
    /**
     * Removes the Client's smile
     * @param from Where the action occured
     * @returns Was it success
     */
    remove_smile(from?: APIFeedFrom): Promise<boolean>;
    /**
     * Unsmiles the post
     * @param from Where the action occured
     * @returns Was it success
     */
    unsmile(from?: APIFeedFrom): Promise<boolean>;
    /**
     * Removes the Client's unsmile
     * @param from Where the content was smiled
     * @returns Was the content marked as smiled
     */
    remove_unsmile(from?: APIFeedFrom): Promise<boolean>;
}
export default Content;
//# sourceMappingURL=Content.d.ts.map