import { APIContentCreator, APINickColor, APIProfilePhoto, APIUserNums, APIUserRating } from "@ifunny/ifunny-api-types";
import { Base } from "./Base";
import { Client } from "../client/Client";
import { User } from "./User";
/**
 * Preresents a Content Creator on iFunny
 * @extends Base<APIContentCreator>
 */
export declare class Creator extends Base<APIContentCreator> {
    #private;
    /**
     * @param client Client instance for the Creator
     * @param payload Payload of the content creator
     */
    constructor(client: Client, payload: APIContentCreator);
    /**
     * The Content Creator's User Object
     */
    user(): Promise<User>;
    /**
     * Is the creator banned
     */
    get is_banned(): boolean;
    /**
     * Is the creator blocked by the Client
     */
    get is_blocked(): boolean;
    /**
     * Is the creator a deleted user
     */
    get is_deleted(): boolean;
    /**
     * Is the creator subscribed to the Client
     */
    get is_subscriber(): boolean;
    /**
     * Is the Client subscribed to the Creator
     */
    get is_subscription(): boolean;
    /**
     * Is the Creator verified
     */
    get is_verified(): boolean;
    /**
     * The creator's nick
     * @alias username
     */
    get nick(): string;
    /**
     * The creator's nick color
     */
    get nick_color(): APINickColor | null;
    /**
     * The creator's nums
     * @alias stats
     */
    get num(): APIUserNums;
    /**
     * The creator's original nick
     */
    get original_nick(): string;
    /**
     * The creator's profile photo
     */
    get photo(): APIProfilePhoto | null;
    /**
     * The creator's rating
     */
    get rating(): APIUserRating;
    /**
     * The creator's stats
     * @alias num
     */
    get stats(): APIUserNums;
    /**
     * Total number of posts the creator has\
     * ? This isn't in Creator.num for some reason
     */
    get total_posts(): number;
    /**
     * The creator's username
     * @alias nick
     */
    get username(): string;
}
export default Creator;
//# sourceMappingURL=Creator.d.ts.map