import { APIProfilePhoto, APISimpleUser, APIUserNums } from "@ifunny/ifunny-api-types";
import { Client } from "../client/Client";
import { Base } from "./Base";
import { User } from "./User";
/**
 * Simple user class, typically found in pagination
 * @extends Base<APISimpleUser>
 */
export declare class SimpleUser extends Base<APISimpleUser> {
    #private;
    /**
     * @param client Client attached to the SimpleUser
     * @param payload Payload for the SimpleUser
     */
    constructor(client: Client, payload: APISimpleUser);
    /**
     * Fetches the User object
     * @returns The User object with more information
     */
    user(): Promise<User | null>;
    /**
     * Is the user banned?
     */
    get is_banned(): boolean;
    /**
     * Is the user blocked by the Client
     */
    get is_blocked(): boolean;
    /**
     * Is the user deleted
     */
    get is_deleted(): boolean;
    /**
     * Is the user subcribed to the Client
     */
    get is_subscriber(): boolean;
    /**
     * Is the Cilent subscribed to the user
     */
    get is_subscription(): boolean;
    /**
     * Is the user verified
     */
    get is_verified(): boolean;
    /**
     * User's nick
     * @alias username
     */
    get nick(): string;
    /**
     * Nums for the user
     * @alias stats
     */
    get num(): APIUserNums;
    /**
     * Stats for the user
     * @alias num
     */
    get stats(): APIUserNums;
    /**
     * Amount of subscribers the user has
     */
    get total_subscribers(): number;
    /**
     * Amount of subcriptions the user has
     */
    get total_subscriptions(): number;
    /**
     * Amount of posts the user has
     */
    get total_posts(): number;
    /**
     * User's nick
     * @alias nick
     */
    get username(): string;
    /**
     * Original nick for the user
     */
    get original_nick(): string;
    /**
     * Profile photo for the user
     */
    get photo(): APIProfilePhoto | null;
}
export default SimpleUser;
//# sourceMappingURL=SimpleUser.d.ts.map