import { APIContentThumbnail } from "@ifunny/ifunny-api-types";
/**
 * Represents a thumbnail for Content on iFunny
 */
export declare class Thumbnail {
    #private;
    static readonly Thumbnail_ID_Regex: RegExp;
    /**
     * @param thumbnail Thumbnail data from the API
     */
    constructor(thumbnail: APIContentThumbnail);
    /**
     * Gets the value for the thumbnail from its key
     * @param key Key for the thumbnail
     * @returns Type safe value from the key
     */
    protected get<K extends keyof APIContentThumbnail>(key: K): APIContentThumbnail[K];
    /**
     * Thumbnail Content Id. This is different from the Content Id
     */
    get id(): string;
    /**
     * Create a new thumbnail with custom parameters
     * @param params Params for the new thumbnail
     * @param extension File extension for the thumbnail. (Default: `jpg`)
     */
    create(params: string, extension?: "jpg" | " webp"): string;
    /**
     * The thumbnail url after cropping out the iFunny Watermark
     */
    get cropped(): string;
    get large_url(): string;
    get large_webp_url(): string;
    get proportional_size(): import("@ifunny/ifunny-api-types").Size;
    get proportional_url(): string;
    get proportional_webp_url(): string;
    get small_url(): string | undefined;
    get url(): string;
    get webp_url(): string;
    get x640_url(): string;
    get x640_webp_url(): string;
}
export default Thumbnail;
//# sourceMappingURL=Thumbnail.d.ts.map